@@ -5,7 +5,7 @@
 from __future__ import absolute_import
 from .series_extras import pack_data_for_series, get_series_padding, pack_input_data_for_series, pack_output_data_for_series
 from .rnn_extras import pack_input_data_for_rnn, pack_output_data_for_rnn
-from .scaler_extras import scale_input_data, scale_output_data
+from .scaler_extras import scale_input_data, scale_output_data, rescale_output_data
 from .input_extras import remove_not_used_inputs
 from .data_extras import prepare_input_data, prepare_output_data
 from .encode_data_set import encode_inputs, encode_output_data, decode_output_data
